@@ -639,14 +639,14 @@ def put_object(
     target_path = os.path.join("s3://", dest_bucket_name, dest_object_name)
     cmd = f"aws s3 cp {src_data} {target_path}"
 
-    # out, err = execute_cmd(cmd)
-    # if err:
-    #     logging.error(
-    #         "Failed to add %s to %s!!",
-    #         os.path.basename(dest_object_name),
-    #         os.path.dirname(dest_object_name),
-    #     )
-    #     return err, False
+    out, err = execute_cmd(cmd)
+    if err:
+        logging.error(
+            "Failed to add %s to %s!!",
+            os.path.basename(dest_object_name),
+            os.path.dirname(dest_object_name),
+        )
+        return err, False
 
     # check for integrity
     obj = boto3.resource("s3").Object(dest_bucket_name, dest_object_name)
